fairly.client package
=====================

Submodules
----------

fairly.client.djehuty module
----------------------------

.. automodule:: fairly.client.djehuty
   :members:
   :undoc-members:
   :show-inheritance:

fairly.client.figshare module
-----------------------------

.. automodule:: fairly.client.figshare
   :members:
   :undoc-members:
   :show-inheritance:

fairly.client.invenio module
---------------------------

.. automodule:: fairly.client.invenio
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: fairly.client
   :members:
   :undoc-members:
   :show-inheritance:
